@@ -1,5 +1,5 @@
 package XML::GrammarBase;
-$XML::GrammarBase::VERSION = '0.2.6';
+$XML::GrammarBase::VERSION = '0.2.7';
 use warnings;
 use strict;
 
@@ -21,7 +21,7 @@ specialized XML grammars.
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 SYNOPSIS
 
@@ -35,10 +35,6 @@ processors for XML grammars (such as those under the XML::Grammar namespace
 
 It provides roles and base classes for facilitating writing those.
 
-=head1 VERSION
-
-version 0.2.6
-
 =head1 SEE ALSO
 
 L<XML::GrammarBase::Role::RelaxNG> , L<XML::GrammarBase::Role::XSLT> .
@@ -134,7 +130,7 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -177,14 +173,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
