@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::DataDir;
-$XML::GrammarBase::Role::DataDir::VERSION = '0.2.6';
+$XML::GrammarBase::Role::DataDir::VERSION = '0.2.7';
 use strict;
 use warnings;
 
@@ -76,7 +76,7 @@ XML::GrammarBase::Role::DataDir - provide the data_dir accessor.
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 SYNOPSIS
 
@@ -94,10 +94,6 @@ version 0.2.6
         data_dir => "/path/to/data-dir",
     );
 
-=head1 VERSION
-
-version 0.2.6
-
 =head1 SLOTS
 
 =head2 module_base
@@ -211,7 +207,7 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -254,14 +250,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
