@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::RelaxNG;
-$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.6';
+$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.7';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ use XML::LibXML '2.0017';
 with('XML::GrammarBase::Role::DataDir');
 
 has 'rng_schema_basename' => ( isa => 'Str', is => 'rw' );
-has '_rng' => (
+has '_rng'                => (
     isa     => 'XML::LibXML::RelaxNG',
     is      => 'rw',
     default => sub { return shift->_calc_default_rng_schema; },
@@ -98,7 +98,7 @@ XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 SYNOPSIS
 
@@ -120,10 +120,6 @@ version 0.2.6
     # Throws an exception on failure.
     $rnger->rng_validate_file("/different-path-to-xml-file.xml");
 
-=head1 VERSION
-
-version 0.2.6
-
 =head1 SLOTS
 
 =head2 module_base
@@ -257,7 +253,7 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -300,14 +296,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
