@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT;
-$XML::GrammarBase::Role::XSLT::VERSION = '0.2.6';
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.7';
 use strict;
 use warnings;
 
@@ -52,7 +52,7 @@ XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 SYNOPSIS
 
@@ -88,10 +88,6 @@ version 0.2.6
         }
     );
 
-=head1 VERSION
-
-version 0.2.6
-
 =head1 PARAMATERS
 
 =head2 output_format
@@ -275,7 +271,7 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -318,14 +314,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
