@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT::Global;
-$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.6';
+$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.7';
 use strict;
 use warnings;
 
@@ -84,7 +84,7 @@ sub perform_xslt_translation
     my ( $self, $args ) = @_;
 
     my $output_format = $args->{output_format};
-    my $encoding = ( $args->{encoding} || 'utf8' );
+    my $encoding      = ( $args->{encoding} || 'utf8' );
 
     my $source_dom = $self->_get_dom_from_source($args);
 
@@ -151,7 +151,7 @@ XML::GrammarBase::Role::XSLT::Global - a base, non-parameterised, role for an XS
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 SYNOPSIS
 
@@ -166,10 +166,6 @@ version 0.2.6
 This is a utility global (non-variant) role used by
 L<XML::GrammarBase::Role::XSLT> . For internal use.
 
-=head1 VERSION
-
-version 0.2.6
-
 =head1 METHODS
 
 =head2 $self->perform_xslt_translation(...)
@@ -265,7 +261,7 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -308,14 +304,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-GrammarBase>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
